@@ -1,7 +1,7 @@
 /* File names and variables for bison,
 
-   Copyright (C) 1984, 1989, 2000-2002, 2006-2007, 2009-2015 Free
-   Software Foundation, Inc.
+   Copyright (C) 1984, 1989, 2000-2002, 2006-2007, 2009-2015, 2018-2019
+   Free Software Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
 
@@ -64,7 +64,9 @@ extern char *all_but_ext;
 void compute_output_file_names (void);
 void output_file_names_free (void);
 
-/** Record that we generate file \a file_name.
+/** Record that we generate a file.
+ *
+ *  \param file_name  the name of file being generated.
  *  \param source whether this is a source file (*c, *.java...)
  *                as opposed to a report (*.output, *.dot...).
  */
